# This is a generated file! Please edit source .ksy file and use kaitai-struct-compiler to rebuild

from pkg_resources import parse_version
import kaitaistruct
from kaitaistruct import KaitaiStruct, KaitaiStream, BytesIO


if parse_version(kaitaistruct.__version__) < parse_version('0.9'):
    raise Exception("Incompatible Kaitai Struct Python API: 0.9 or later is required, but you have %s" % (kaitaistruct.__version__))

class Sanosat1(KaitaiStruct):
    """:field delimiter: sanosat1_telemetry.delimiter
    :field callsign: sanosat1_telemetry.callsign
    :field packet_type: sanosat1_telemetry.packet_type
    :field com_temperature: sanosat1_telemetry.com_temperature
    :field battery_voltage: sanosat1_telemetry.battery_voltage
    :field charging_current: sanosat1_telemetry.charging_current
    :field battery_temperature: sanosat1_telemetry.battery_temperature
    :field radiation_level: sanosat1_telemetry.radiation_level
    :field no_of_resets: sanosat1_telemetry.no_of_resets
    :field antenna_deployment_status: sanosat1_telemetry.antenna_deployment_status
    """
    def __init__(self, _io, _parent=None, _root=None):
        self._io = _io
        self._parent = _parent
        self._root = _root if _root else self
        self._read()

    def _read(self):
        self.sanosat1_telemetry = Sanosat1.Sanosat1TelemetryT(self._io, self, self._root)

    class Sanosat1TelemetryT(KaitaiStruct):
        def __init__(self, _io, _parent=None, _root=None):
            self._io = _io
            self._parent = _parent
            self._root = _root if _root else self
            self._read()

        def _read(self):
            self.delimiter = self._io.read_s4le()
            if not  ((self.delimiter == 65535)) :
                raise kaitaistruct.ValidationNotAnyOfError(self.delimiter, self._io, u"/types/sanosat1_telemetry_t/seq/0")
            self.callsign = (KaitaiStream.bytes_terminate(self._io.read_bytes(7), 0, False)).decode(u"ASCII")
            if not  ((self.callsign == u"AM9NPQ")) :
                raise kaitaistruct.ValidationNotAnyOfError(self.callsign, self._io, u"/types/sanosat1_telemetry_t/seq/1")
            self.packet_type = self._io.read_s2le()
            self.com_temperature = self._io.read_s2le()
            self.battery_voltage = self._io.read_s2le()
            self.charging_current = self._io.read_s2le()
            self.battery_temperature = self._io.read_s2le()
            self.radiation_level = self._io.read_s2le()
            self.no_of_resets = self._io.read_s2le()
            self.antenna_deployment_status = self._io.read_u1()






"""
`pytest` testing framework file for Entrysat
"""

import satnogsdecoders.decoder as decoder
from tests.shared_methods import check_type, load_objects


def test_answer():  # pylint: disable=too-many-locals
    """
    `pytest` entry point
    """

    example1 = bytearray([
        0x8c, 0x6c, 0x96, 0xa8, 0x82, 0x40, 0xe0, 0x9e, 0x9c, 0x60, 0x64, 0x8c,
        0xa4, 0x61, 0x03, 0xf0, 0x00, 0x00, 0x00, 0x00, 0x08, 0x01, 0xc7, 0x29,
        0x00, 0x12, 0x10, 0x03, 0x19, 0x23, 0xfe, 0xbd, 0xcd, 0x17, 0x06, 0x00,
        0xf1, 0x6b, 0x00, 0x00, 0x9e, 0xa0, 0x98, 0x1f, 0xc6, 0xb0, 0x09, 0xbe,
        0xfe, 0x23
    ])
    example1_keys = 23
    packets = [example1]
    dut = 'Entrysat'
    result = []

    for frame in packets:
        result = load_objects(decoder, dut, frame)
        count = check_type(result)
        if frame == example1:
            assert count == example1_keys



"""
decode a single binary frame
"""

from __future__ import print_function

import argparse
import json

from satnogsdecoders import decoder


def decode_frame(decoder_name, raw_frame):
    """
    decoding function
    """

    decoder_class = getattr(decoder, decoder_name.capitalize())
    frame = decoder_class.from_bytes(raw_frame)

    fields = decoder.get_fields(frame, empty=False)
    return fields


def main():
    """
    main entry point
    """

    parser = argparse.ArgumentParser(
        description='Decode a raw frame with the selected decoder'
        '(generated by Kaitai) and print its json representation.')
    parser.add_argument('decoder_name',
                        type=str,
                        help='name of the decoder (e.g. siriussat)')
    parser.add_argument('raw_frame_file',
                        type=str,
                        help='Path to the file containing the raw frame')
    args = parser.parse_args()

    # Load the raw frame
    with open(args.raw_frame_file, 'rb') as rawfile:
        raw_frame = rawfile.read()

    fields = decode_frame(args.decoder_name, raw_frame)
    print(json.dumps(fields, indent=4, sort_keys=False))
